@@ -13,6 +13,7 @@ ENABLE_KEYSTONE="${ENABLE_KEYSTONE:-false}"
 ZUUL_BRANCH=${ZUUL_BRANCH:-}
 ENABLE_VENV=true
 CLI_TEST=${CLI_TEST:-false}
+BOOT_MODE=${BOOT_MODE:-}
 
 # Set defaults for ansible command-line options to drive the different
 # tests.
@@ -40,7 +41,7 @@ DOWNLOAD_IPA=true
 CREATE_IPA_IMAGE=false
 WRITE_INTERFACES_FILE=true
 PROVISION_WAIT_TIMEOUT=${PROVISION_WAIT_TIMEOUT:-900}
-NOAUTH_MODE=true
+NOAUTH_MODE=${NOAUTH_MODE:-true}
 CLOUD_CONFIG=""
 WAIT_FOR_DEPLOY=true
 
@@ -54,6 +55,10 @@ if [ "$ZUUL_BRANCH" != "" ]; then
     VM_SETUP_EXTRA="--storage-pool-path /opt/libvirt/images"
 fi
 
+if [ -d "${WORKSPACE:-}" ]; then
+    BIFROST_CLI_EXTRA="${BIFROST_CLI_EXTRA:-} --extra-vars copy_from_local_path=true"
+fi
+
 source $SCRIPT_HOME/env-setup.sh
 
 # Note(cinerama): activate is not compatible with "set -u";
@@ -93,7 +98,11 @@ elif [ ${BUILD_IMAGE} = "true" ]; then
     fi
 elif [ ${ENABLE_KEYSTONE} = "true" ]; then
     NOAUTH_MODE=false
-    CLOUD_CONFIG="-e cloud_name=bifrost"
+    CLOUD_CONFIG+=" -e cloud_name=bifrost"
+fi
+
+if [[ -n "$BOOT_MODE" ]]; then
+    CLOUD_CONFIG+=" -e default_boot_mode=$BOOT_MODE"
 fi
 
 logs_on_exit() {
@@ -123,7 +132,10 @@ done
     --memory ${VM_MEMORY_SIZE:-512} \
     --disk ${VM_DISK:-5} \
     --inventory "${BAREMETAL_DATA_FILE}" \
-    ${VM_SETUP_EXTRA:-}
+    --driver ${TEST_VM_NODE_DRIVER:-ipmi} \
+    --extra-vars git_url_root="${WORKSPACE:-https://opendev.org}" \
+    ${VM_SETUP_EXTRA:-} \
+    ${BIFROST_CLI_EXTRA:-}
 
 if [ ${USE_DHCP} = "true" ]; then
     # reduce the number of nodes in JSON file
@@ -136,13 +148,9 @@ if [ ${USE_DHCP} = "true" ]; then
 fi
 
 if [ ${CLI_TEST} = "true" ]; then
-    # FIXME(dtantsur): bifrost-cli does not use opendev-provided repos.
-    ../bifrost-cli --debug install --release ${ZUUL_BRANCH:-master} --testenv
-    CLOUD_CONFIG+=" -e skip_install=true"
-    CLOUD_CONFIG+=" -e skip_package_install=true"
-    CLOUD_CONFIG+=" -e skip_bootstrap=true"
-    CLOUD_CONFIG+=" -e skip_start=true"
-    CLOUD_CONFIG+=" -e skip_migrations=true"
+    ../bifrost-cli --debug install --testenv \
+        --extra-vars git_url_root="${WORKSPACE:-https://opendev.org}" \
+        ${BIFROST_CLI_EXTRA:-}
 fi
 
 set +e
@@ -173,6 +181,11 @@ ${ANSIBLE} -vvvv \
     -e use_public_urls=${ENABLE_KEYSTONE} \
     -e wait_for_node_deploy=${WAIT_FOR_DEPLOY} \
     -e not_enrolled_data_file=${BAREMETAL_DATA_FILE}.rest \
+    -e skip_install=${CLI_TEST} \
+    -e skip_package_install=${CLI_TEST} \
+    -e skip_bootstrap=${CLI_TEST} \
+    -e skip_start=${CLI_TEST} \
+    -e skip_migrations=${CLI_TEST} \
     ${CLOUD_CONFIG}
 EXITCODE=$?
 
